-- CreateTable
CREATE TABLE "Accommodation" (
    "id" TEXT NOT NULL,
    "name" TEXT NOT NULL,
    "description" TEXT NOT NULL,
    "mainPhoto" TEXT NOT NULL,
    "location" TEXT NOT NULL,
    "addedAt" TIMESTAMP(3) NOT NULL,
    "userId" TEXT NOT NULL,
    "price" DOUBLE PRECISION NOT NULL,

    CONSTRAINT "Accommodation_pkey" PRIMARY KEY ("id")
);

-- CreateTable
CREATE TABLE "Reservation" (
    "id" TEXT NOT NULL,
    "from" TIMESTAMP(3) NOT NULL,
    "to" TIMESTAMP(3) NOT NULL,
    "guestCount" INTEGER NOT NULL,
    "reservedAt" TIMESTAMP(3) NOT NULL,
    "canceledAt" TIMESTAMP(3),
    "accommodationId" TEXT NOT NULL,
    "userId" TEXT NOT NULL,
    "isPaid" BOOLEAN NOT NULL DEFAULT false,

    CONSTRAINT "Reservation_pkey" PRIMARY KEY ("id")
);

-- CreateTable
CREATE TABLE "User" (
    "id" TEXT NOT NULL,
    "name" TEXT NOT NULL,
    "avatar" TEXT NOT NULL,
    "email" TEXT NOT NULL,

    CONSTRAINT "User_pkey" PRIMARY KEY ("id")
);


-- AddForeignKey
ALTER TABLE "Accommodation" ADD CONSTRAINT "Accommodation_userId_fkey" FOREIGN KEY ("userId") REFERENCES "User"("id") ON DELETE RESTRICT ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE "Reservation" ADD CONSTRAINT "Reservation_accommodationId_fkey" FOREIGN KEY ("accommodationId") REFERENCES "Accommodation"("id") ON DELETE RESTRICT ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE "Reservation" ADD CONSTRAINT "Reservation_userId_fkey" FOREIGN KEY ("userId") REFERENCES "User"("id") ON DELETE RESTRICT ON UPDATE CASCADE;


INSERT INTO "User" (id, name, avatar, email) VALUES ('9447ca3b-92f0-4fb1-a9fc-90bf7ee4cb30', 'Jose', 'jose.jpeg', '485342.jose@mailinator.com');
INSERT INTO "User" (id, name, avatar, email) VALUES ('6b143cf5-dc36-431e-a7a1-202444e75786', 'Daniela', 'daniela.jpeg', '485342.daniela@mailinator.com');
INSERT INTO "User" (id, name, avatar, email) VALUES ('ca9b9472-578b-4f5a-baf0-4ae851bccd8d', 'Tom', 'tom.jpeg', '485342.tom@mailinator.com');
INSERT INTO "User" (id, name, avatar, email) VALUES ('3f038d4b-9857-46b0-b36a-6b893b7fc8ca', 'Clara', 'clara.jpeg', '485342.clara@mailinator.com');
INSERT INTO "User" (id, name, avatar, email) VALUES ('5a8f2697-5fbe-4a25-8168-da5c20810874', 'Lara', 'lara.jpeg', '485342.lara@mailinator.com');

INSERT INTO "Accommodation" (id, name, description, "mainPhoto", location, "addedAt", "userId", price) VALUES ('53efd933-f722-4575-983d-75750ad97365', 'Å Auge - River Eye - Treehouse', 'Experience being in the trees, falling asleep under the stars and waking up to the sound of birdsong in this spectacular treehouse. If you are looking for an intimate, simple and restful retreat, look no further.', 'photo-1550355191-aa8a80b41353.jpeg', 'Tinn, Telemark, Nórsko', '2021-09-27', '3f038d4b-9857-46b0-b36a-6b893b7fc8ca', 50);
INSERT INTO "Accommodation" (id, name, description, "mainPhoto", location, "addedAt", "userId", price) VALUES ('2f0ff579-40d1-4586-932c-b8b78421acbb', 'Aska Modern Cabin', 'Aska is a part of Hlíð Ferðaþjónusta is a complex of accommodations on the northern shore of lake Mývatn, right beneath the airport. We are situated about one kilometer away from the lakeside, in the middle of a 300 years old lava field and with a fantastic view over the lake.', 'photo-1579033462043-0f11a7862f7d.jpeg', 'Reykjahlíð, Island', '2021-10-27', '5a8f2697-5fbe-4a25-8168-da5c20810874', 60);
INSERT INTO "Accommodation" (id, name, description, "mainPhoto", location, "addedAt", "userId", price) VALUES ('9c14e680-62b4-4af6-b817-296610922ae9', 'Glass cottage with Hot tub "Blár"', 'We are located on a lava desert in the south of Iceland. 5 minutes from the small town of Hella, close to all the popular attractions that southern Iceland has to offer, but also in a secret and secluded location.', 'photo-1590725121839-892b458a74fe.jpeg', 'Hella, Island', '2022-09-27', 'ca9b9472-578b-4f5a-baf0-4ae851bccd8d', 70);
INSERT INTO "Accommodation" (id, name, description, "mainPhoto", location, "addedAt", "userId", price) VALUES ('8a4e0e83-fd0d-4d45-b6ad-1de458942dff', 'The Mud House', 'Beautiful mud brick, earth roof open plan small house. Set in an abundant organic paradise of birds and orchards surrounded by regenerating bush within walking distance to the water in peaceful Pigeon Bay. ', 'photo-1590725140246-20acdee442be.jpeg', 'Pigeon Bay, Canterbury, Nový Zéland', '2022-10-27', '6b143cf5-dc36-431e-a7a1-202444e75786', 37);
INSERT INTO "Accommodation" (id, name, description, "mainPhoto", location, "addedAt", "userId", price) VALUES ('35a23b2f-288e-4b87-b941-c2e4da2f256e', 'Casa Tata 4', 'These gorgeous 9 cabins right in front of the sea are the perfect spot if you want to enjoy Chacahua’s captivating nature and still have a clean, quiet, luxurious and tasteful accommodation.', 'photo-1619292585355-ab0e3fd509fe.jpeg', 'Laguna de Chacahua, Oaxaca, Mexiko', '2023-03-23', '9447ca3b-92f0-4fb1-a9fc-90bf7ee4cb30', 45);

INSERT INTO "Reservation" (id, "from", "to", "guestCount", "reservedAt", "accommodationId", "userId") VALUES ('84d37846-88f2-4692-b788-0c62e48b39db', '2023-03-24', '2023-03-27', 3, '2023-03-24', '2f0ff579-40d1-4586-932c-b8b78421acbb', '5a8f2697-5fbe-4a25-8168-da5c20810874');
INSERT INTO "Reservation" (id, "from", "to", "guestCount", "reservedAt", "accommodationId", "userId") VALUES ('4b52822e-37cc-498b-b516-32d7ccbc7299', '2023-03-24', '2023-03-27', 2, '2023-03-24', '53efd933-f722-4575-983d-75750ad97365', '6b143cf5-dc36-431e-a7a1-202444e75786');

CREATE TABLE "Subscription" (
    "id" SERIAL PRIMARY KEY,
    "userId" TEXT NOT NULL,
    "accommodationId" TEXT NOT NULL
);

-- AddForeignKey
ALTER TABLE "Subscription" ADD CONSTRAINT "Subscription_userId_fkey" FOREIGN KEY ("userId") REFERENCES "User"("id") ON DELETE RESTRICT ON UPDATE CASCADE;

-- AddForeignKey
ALTER TABLE "Subscription" ADD CONSTRAINT "Subscription_accommodationId_fkey" FOREIGN KEY ("accommodationId") REFERENCES "Accommodation"("id") ON DELETE RESTRICT ON UPDATE CASCADE;

INSERT INTO "Subscription" ("userId", "accommodationId") VALUES
    ('9447ca3b-92f0-4fb1-a9fc-90bf7ee4cb30', '2f0ff579-40d1-4586-932c-b8b78421acbb'),
    ('9447ca3b-92f0-4fb1-a9fc-90bf7ee4cb30', '53efd933-f722-4575-983d-75750ad97365'),
    ('9447ca3b-92f0-4fb1-a9fc-90bf7ee4cb30', '9c14e680-62b4-4af6-b817-296610922ae9'),
    ('9447ca3b-92f0-4fb1-a9fc-90bf7ee4cb30', '8a4e0e83-fd0d-4d45-b6ad-1de458942dff'),
    ('9447ca3b-92f0-4fb1-a9fc-90bf7ee4cb30', '35a23b2f-288e-4b87-b941-c2e4da2f256e'),
    ('6b143cf5-dc36-431e-a7a1-202444e75786', '35a23b2f-288e-4b87-b941-c2e4da2f256e'),
    ('ca9b9472-578b-4f5a-baf0-4ae851bccd8d', '35a23b2f-288e-4b87-b941-c2e4da2f256e'),
    ('3f038d4b-9857-46b0-b36a-6b893b7fc8ca', '35a23b2f-288e-4b87-b941-c2e4da2f256e'),
    ('5a8f2697-5fbe-4a25-8168-da5c20810874', '35a23b2f-288e-4b87-b941-c2e4da2f256e')
;

     