import { Request, Response, NextFunction } from "express";
import jwt from "jsonwebtoken";
import unless from "express-unless";

const JWT_SECRET = 'secret_from_dotenv';

// originally used express-jwt, which worked just fine, except for the fact I was getting some bs errors
//   when using ExpressJwtRequest as a type for 'req' instead of express.Request..
//   .. even tho ExpressJwtRequest is literally just 'express.Request & {auth: jwt.JwtPayload;}', so idk wtf was going on there
// that error was solved only using @ts-ignore (or by removing compilerOptions.strict = true from tsconfig :D ),
//   but managed to make it work with just 'jsonwebtoken' functionality, which doesn't require any custom Request types
//   and works just fine
const checkJwt = (req: Request, res: Response, next: NextFunction) => {
  
  const token = getToken(req);
  if (!token) {
    res.status(401).send({
      status: "error",
      data: {},
      message: "Authentication failed - invalid token"
    });
    return;
  }
  
  try {
    res.locals.jwtPayload = jwt.verify(token, JWT_SECRET);
  } catch (error) {
    res.status(401).send({
      status: "error",
      data: {},
      message: "Authentication failed - invalid token"});
    return;
  }

  next();
};

checkJwt.unless = unless;

function getToken(req: Request): string | undefined | null {
  // handle token presented as a Bearer token in the Authorization header
  if (req.headers.authorization && req.headers.authorization.split(' ')[0] === 'Bearer') {    
    return req.headers.authorization.split(' ')[1];
  };
  // check cookies
  if (req.cookies && req.cookies.token) {
    return req.cookies.auth;
  }
  return null; 
}

export default checkJwt;