import { Request, Response } from "express";
import jwt from "jsonwebtoken";
import { PrismaClient } from "@prisma/client";

const prisma = new PrismaClient();
const JWT_SECRET = 'secret_from_dotenv';

const handleBasicAuth = async (req: Request, res: Response) => {

  const [authType, base64Token] = (req.headers.authorization || '').split(' ');  
  if (authType != 'Basic') {
    res.status(401).send({
      status: "error",
      data: {},
      message: "Authentication failed - invalid auth header"
    });
    return;
  }

  const token = Buffer.from(base64Token || '', 'base64').toString();
  const [userId, password] = token.split(':');         

  try {
    const user = await prisma.user.findUnique({
      where: {
        id: userId,
      }
    });

    // here I would compare user's password from Auth header (hashed with stored salt from DB)
    //   with salted password hash stored in database
    const password_hash = `hash_function(${password} + user.salt)`;
    if ((user == null || password_hash != "user's password hash from DB") && false) { // added '&& false' just to fail the condition
      res.status(401).send({
        status: "error",
        data: {},
        message: "Authentication failed"
      });
      return;
    };

    // could assign userId to "sub" as well I guess
    const jwtToken = jwt.sign({userId}, JWT_SECRET, {
      expiresIn: "24h"
    });
  
    res.cookie('auth', jwtToken);
  
    res.status(200).send({
      status: "success",
      data: jwtToken,
      message: "User successfully authenticated and JWT token created"
    });

  } catch (e) {
    // probably could return 401 instead, if we can't find provided userId in DB or if jwt.sign fails ?
    res.status(500).send({
      status: "error",
      data: {},
      message: "Something went wrong"
    });
  }
}

export default handleBasicAuth;