import { Request, Response } from 'express';
import { accommodations } from '.';
import { prismaMock } from '../singleton';

describe("AirBnb API",  () => {
    test("should store invalid accommodation object", async () => {
        const status = jest.fn().mockReturnThis();
        const send = jest.fn().mockReturnThis()

        // we also have to mock the JWT token payload, otherwise we will be getting sometimes 500, especially when inserting to DB,
        //  (since the property 'jwtPayload' doesn't exist in mock response)
        const response: Partial<Response> = { status, send, locals: {jwtPayload: {userId: "3f038d4b-9857-46b0-b36a-6b893b7fc8ca"}}}
        const request: Partial<Request> = {            
            body: {
                "name": "Generic AirBnb",
                "description": "Very cozy 10/10",
                "mainPhoto": "generic_airbnb.jpeg",
                "location": "Tinn, Telemark, Nórsko",              
                "userId": "3f038d4b-9857-46b0-b36a-6b893b7fc8ca"
            },
        }

        await accommodations.store(request as Request, response as Response);

        expect(status).toBeCalledWith(400);
        expect(send).toBeCalledWith({
            "data": ["price is a required field"],
            "message": "price is a required field",
            "status": "error"
        });
        expect(prismaMock.accommodation.create.mock.calls).toHaveLength(0);
    });

    test("should store valid accommodation object", async () => {
        const status = jest.fn().mockReturnThis();
        const send = jest.fn().mockReturnThis();

        const response: Partial<Response> = { status, send, locals: {jwtPayload: {userId: "3f038d4b-9857-46b0-b36a-6b893b7fc8ca"}} };
        const request: Partial<Request> = {
            body: {
                "name": "Generic AirBnb",
                "description": "Very cozy 10/10",
                "mainPhoto": "generic_airbnb.jpeg",
                "location": "Tinn, Telemark, Nórsko",
                "userId": "3f038d4b-9857-46b0-b36a-6b893b7fc8ca",
                "price": 50                
            },
        };
        prismaMock.accommodation.create.mockResolvedValueOnce({
            "id": "3b78dc1e-45bd-4987-92f2-830f15f5ff73",          
            "name": "Generic AirBnb",
            "description": "Very cozy 10/10",
            "mainPhoto": "generic_airbnb.jpeg",
            "location": "Tinn, Telemark, Nórsko",
            "addedAt": new Date("2022-04-09T14:33:45.087Z"),       
            "userId": "3f038d4b-9857-46b0-b36a-6b893b7fc8ca",
            "price": 50,            
        });
        await accommodations.store(request as Request, response as Response);
        
        expect(status).toBeCalledWith(201);
        expect(send).toBeCalledWith({
            "data":  {
                "id": "3b78dc1e-45bd-4987-92f2-830f15f5ff73",          
                "name": "Generic AirBnb",
                "description": "Very cozy 10/10",
                "mainPhoto": "generic_airbnb.jpeg",
                "location": "Tinn, Telemark, Nórsko",
                "addedAt": new Date("2022-04-09T14:33:45.087Z"),           
                "userId": "3f038d4b-9857-46b0-b36a-6b893b7fc8ca",
                "price": 50,
            },
            "message": "Accommodation stored in system",
            "status": "success",
        });
        expect(prismaMock.accommodation.create.mock.calls).toHaveLength(1);
    });
});