import { Request, Response } from 'express';
import { reservations } from '.';
import { prismaMock } from '../singleton';

describe("AirBnb API",  () => {
    test("should store invalid reservation object", async () => {
        const status = jest.fn().mockReturnThis();
        const send = jest.fn().mockReturnThis()

        const response: Partial<Response> = { status, send, locals: {jwtPayload: {userId: "5a8f2697-5fbe-4a25-8168-da5c20810874"}} }
        const request: Partial<Request> = {            
            body: {
                "from": new Date(1644846274000),
                "to": new Date(1644209756000),                                
                "accommodationId": "2f0ff579-40d1-4586-932c-b8b78421acbb",
                "userId": "5a8f2697-5fbe-4a25-8168-da5c20810874"               
            },
        }

        await reservations.store(request as Request, response as Response);

        expect(status).toBeCalledWith(400);
        expect(send).toBeCalledWith({
            "data": ["guestCount is a required field"],
            "message": "guestCount is a required field",
            "status": "error"
        });
        expect(prismaMock.reservation.create.mock.calls).toHaveLength(0);
    });

    test("should store valid reservation object", async () => {
        const status = jest.fn().mockReturnThis();
        const send = jest.fn().mockReturnThis();

        const response: Partial<Response> = { status, send, locals: {jwtPayload: {userId: "5a8f2697-5fbe-4a25-8168-da5c20810874"}} };
        const request: Partial<Request> = {
            body: {
                "from": new Date(1667004096000),
                "to": new Date(1668004096000),               
                "guestCount": 3,                                 
                "accommodationId": "2f0ff579-40d1-4586-932c-b8b78421acbb",
                "userId": "5a8f2697-5fbe-4a25-8168-da5c20810874"               
            },
        };
        prismaMock.reservation.create.mockResolvedValueOnce({
            "id": "84d37846-88f2-4692-b788-0c62e48b39db",          
            "from": new Date(1667004096000),
            "to": new Date(1668004096000),
            "guestCount": 3,
            "reservedAt": new Date("2022-04-09T14:33:45.087Z"),
            "canceledAt": null,            
            "accommodationId": "2f0ff579-40d1-4586-932c-b8b78421acbb",
            "userId": "5a8f2697-5fbe-4a25-8168-da5c20810874",
            "isPaid": false       
        });
        await reservations.store(request as Request, response as Response);
        
        expect(status).toBeCalledWith(201);
        expect(send).toBeCalledWith({
            "data":  {
                "id": "84d37846-88f2-4692-b788-0c62e48b39db",          
                "from": new Date(1667004096000),
                "to": new Date(1668004096000),
                "guestCount": 3,
                "reservedAt": new Date("2022-04-09T14:33:45.087Z"),  
                "canceledAt": null,            
                "accommodationId": "2f0ff579-40d1-4586-932c-b8b78421acbb",
                "userId": "5a8f2697-5fbe-4a25-8168-da5c20810874",
                "isPaid": false       
            },
            "message": "Reservation stored in system",
            "status": "success",
        });
        expect(prismaMock.reservation.create.mock.calls).toHaveLength(1);
    });
});