import express from "express";
import { PrismaClient } from "@prisma/client";
import { formatDistance } from 'date-fns';

const prisma = new PrismaClient();

const accommodationRouter = express.Router();

// if no ID is specified
accommodationRouter.get("/", async (_, res) => {
  try {
    const accommodationsData = await prisma.accommodation.findMany();
    // not sure if there is a 'strategy' on how to pick top accommodation
    const topPickAccommodation = accommodationsData.length > 0 ? accommodationsData[0] : null;
    res.render("index.twig", {
      accommodations: accommodationsData,
      topPickAccommodation: topPickAccommodation
    });
  } catch (e) {
    res.render("index.twig", {
      accommodations: [],
      topPickAccommodation: null
    });
  }
});

// when an ID is specified
accommodationRouter.get("/:id", async (req, res) => {
  const accommodationId = req.params.id;

  try {
    const accommodation = await prisma.accommodation.findFirst({
      where: {
        id: accommodationId,
      },
      include: {
        host: true,
      }
    });
  
    if (!accommodation) {
      res.render("accommodation.twig", {
        error: "No accommodation found!",
        pageTitle: "Accommodation Page - unknown"        
      });
      return;
    };

    res.render("accommodation.twig", {      
      pageTitle: `AirBnb - ${accommodation.name}`,
      accommodation: accommodation,
      // have to supply this function to twig, since I couldn't figure out how to define js/ts functions directly in twig
      addedTimeAgo: (addedAt: Date): string => formatDistance(new Date(addedAt), new Date(), { addSuffix: true }),
    });

  } catch (error) {
    res.render("accommodation.twig", {
      error: "An unknown error occurred!",
      pageTitle: "Accommodation Page - unknown"        
    });
  }
});

export default accommodationRouter;
